@@ -1,23 +1,27 @@
 import torch.nn as nn
-import torchquantum as tq
 import torch.nn.utils.prune
 
 from typing import Any, Callable, Dict
 from torchpack.train import Trainer
 from torchpack.utils.typing import Optimizer, Scheduler
 from torchpack.utils.config import configs
-from torchquantum.utils import (get_unitary_loss, legalize_unitary,
-                                build_module_op_list)
+from torchquantum.utils import get_unitary_loss, build_module_op_list
 from torchpack.utils.logging import logger
 from torchpack.callbacks.writers import TFEventWriter
 from torchpack.train.exception import StopTraining
 
-__all__ = ['QTrainer', 'ParamsShiftTrainer']
+__all__ = ["QTrainer", "ParamsShiftTrainer"]
 
 
 class QTrainer(Trainer):
-    def __init__(self, *, model: nn.Module, criterion: Callable,
-                 optimizer: Optimizer, scheduler: Scheduler) -> None:
+    def __init__(
+        self,
+        *,
+        model: nn.Module,
+        criterion: Callable,
+        optimizer: Optimizer,
+        scheduler: Scheduler,
+    ) -> None:
         self.model = model
         self.legalized_model = None
         self.criterion = criterion
@@ -29,18 +33,14 @@ class QTrainer(Trainer):
     def _before_epoch(self) -> None:
         self.model.train()
 
-    def run_step(self, feed_dict: Dict[str, Any], legalize=False) -> Dict[
-            str, Any]:
+    def run_step(self, feed_dict: Dict[str, Any], legalize=False) -> Dict[str, Any]:
         output_dict = self._run_step(feed_dict, legalize=legalize)
         return output_dict
 
-    def _run_step(self, feed_dict: Dict[str, Any], legalize=False) -> Dict[
-            str, Any]:
-        if configs.run.device == 'gpu':
-            inputs = feed_dict[configs.dataset.input_name].cuda(
-                non_blocking=True)
-            targets = feed_dict[configs.dataset.target_name].cuda(
-                non_blocking=True)
+    def _run_step(self, feed_dict: Dict[str, Any], legalize=False) -> Dict[str, Any]:
+        if configs.run.device == "gpu":
+            inputs = feed_dict[configs.dataset.input_name].cuda(non_blocking=True)
+            targets = feed_dict[configs.dataset.target_name].cuda(non_blocking=True)
         else:
             inputs = feed_dict[configs.dataset.input_name]
             targets = feed_dict[configs.dataset.target_name]
@@ -57,37 +57,36 @@ class QTrainer(Trainer):
             if configs.regularization.unitary_loss_lambda_trainable:
                 loss += self.model.unitary_loss_lambda[0] * unitary_loss
             else:
-                loss += configs.regularization.unitary_loss_lambda * \
-                        unitary_loss
+                loss += configs.regularization.unitary_loss_lambda * unitary_loss
 
         if loss.requires_grad:
             for k, group in enumerate(self.optimizer.param_groups):
-                self.summary.add_scalar(f'lr/lr_group{k}', group['lr'])
-            self.summary.add_scalar('loss', loss.item())
-            self.summary.add_scalar('nll_loss', nll_loss)
-            if getattr(self.model, 'sample_arch', None) is not None:
+                self.summary.add_scalar(f"lr/lr_group{k}", group["lr"])
+            self.summary.add_scalar("loss", loss.item())
+            self.summary.add_scalar("nll_loss", nll_loss)
+            if getattr(self.model, "sample_arch", None) is not None:
                 for writer in self.summary.writers:
                     if isinstance(writer, TFEventWriter):
                         writer.writer.add_text(
-                            'sample_arch', str(self.model.sample_arch),
-                            self.global_step)
+                            "sample_arch", str(self.model.sample_arch), self.global_step
+                        )
 
             if configs.regularization.unitary_loss:
                 if configs.regularization.unitary_loss_lambda_trainable:
                     self.summary.add_scalar(
-                        'u_loss_lambda',
-                        self.model.unitary_loss_lambda.item())
+                        "u_loss_lambda", self.model.unitary_loss_lambda.item()
+                    )
                 else:
                     self.summary.add_scalar(
-                        'u_loss_lambda',
-                        configs.regularization.unitary_loss_lambda)
-                self.summary.add_scalar('u_loss', unitary_loss.item())
+                        "u_loss_lambda", configs.regularization.unitary_loss_lambda
+                    )
+                self.summary.add_scalar("u_loss", unitary_loss.item())
 
             self.optimizer.zero_grad()
             loss.backward()
             self.optimizer.step()
 
-        return {'outputs': outputs, 'targets': targets}
+        return {"outputs": outputs, "targets": targets}
 
     def _after_epoch(self) -> None:
         self.model.eval()
@@ -105,43 +104,41 @@ class QTrainer(Trainer):
     def _state_dict(self) -> Dict[str, Any]:
         state_dict = dict()
         # need to store model arch because of randomness of random layers
-        state_dict['model_arch'] = self.model
-        state_dict['model'] = self.model.state_dict()
-        state_dict['optimizer'] = self.optimizer.state_dict()
-        state_dict['scheduler'] = self.scheduler.state_dict()
-        if getattr(self.model, 'sample_arch', None) is not None:
-            state_dict['sample_arch'] = self.model.sample_arch
+        state_dict["model_arch"] = self.model
+        state_dict["model"] = self.model.state_dict()
+        state_dict["optimizer"] = self.optimizer.state_dict()
+        state_dict["scheduler"] = self.scheduler.state_dict()
+        if getattr(self.model, "sample_arch", None) is not None:
+            state_dict["sample_arch"] = self.model.sample_arch
 
         if self.solution is not None:
-            state_dict['solution'] = self.solution
-            state_dict['score'] = self.score
+            state_dict["solution"] = self.solution
+            state_dict["score"] = self.score
 
-        if getattr(self.model, 'encoder', None) is not None:
-            if getattr(self.model.encoder, 'func_list', None) is not None:
-                state_dict['encoder_func_list'] = self.model.encoder.func_list
+        if getattr(self.model, "encoder", None) is not None:
+            if getattr(self.model.encoder, "func_list", None) is not None:
+                state_dict["encoder_func_list"] = self.model.encoder.func_list
 
-        if getattr(self.model, 'q_layer', None) is not None:
-            state_dict['q_layer_op_list'] = build_module_op_list(
-                self.model.q_layer)
+        if getattr(self.model, "q_layer", None) is not None:
+            state_dict["q_layer_op_list"] = build_module_op_list(self.model.q_layer)
 
-        if getattr(self.model, 'measure', None) is not None:
-            if getattr(self.model.measure,
-                       'v_c_reg_mapping', None) is not None:
-                state_dict['v_c_reg_mapping'] = \
-                    self.model.measure.v_c_reg_mapping
+        if getattr(self.model, "measure", None) is not None:
+            if getattr(self.model.measure, "v_c_reg_mapping", None) is not None:
+                state_dict["v_c_reg_mapping"] = self.model.measure.v_c_reg_mapping
 
-        if getattr(self.model, 'nodes', None) is not None:
-            state_dict['encoder_func_list'] = [
-                node.encoder.func_list for node in self.model.nodes]
+        if getattr(self.model, "nodes", None) is not None:
+            state_dict["encoder_func_list"] = [
+                node.encoder.func_list for node in self.model.nodes
+            ]
             if configs.model.transpile_before_run:
                 # only save op_list if transpile before run
-                state_dict['q_layer_op_list'] = [
-                    build_module_op_list(node.q_layer) for node in
-                    self.model.nodes]
-            state_dict['v_c_reg_mapping'] = [
-                node.measure.v_c_reg_mapping for node in self.model.nodes]
-        for attr in ['v_c_reg_mapping', 'encoder_func_list',
-                     'q_layer_op_list']:
+                state_dict["q_layer_op_list"] = [
+                    build_module_op_list(node.q_layer) for node in self.model.nodes
+                ]
+            state_dict["v_c_reg_mapping"] = [
+                node.measure.v_c_reg_mapping for node in self.model.nodes
+            ]
+        for attr in ["v_c_reg_mapping", "encoder_func_list", "q_layer_op_list"]:
             if state_dict.get(attr, None) is None:
                 logger.warning(f"No {attr} found, will not save it.")
 
@@ -149,13 +146,19 @@ class QTrainer(Trainer):
 
     def _load_state_dict(self, state_dict: Dict[str, Any]) -> None:
         # self.model.load_state_dict(state_dict['model'])
-        self.optimizer.load_state_dict(state_dict['optimizer'])
-        self.scheduler.load_state_dict(state_dict['scheduler'])
+        self.optimizer.load_state_dict(state_dict["optimizer"])
+        self.scheduler.load_state_dict(state_dict["scheduler"])
 
 
 class ParamsShiftTrainer(Trainer):
-    def __init__(self, *, model: nn.Module, criterion: Callable,
-                 optimizer: Optimizer, scheduler: Scheduler) -> None:
+    def __init__(
+        self,
+        *,
+        model: nn.Module,
+        criterion: Callable,
+        optimizer: Optimizer,
+        scheduler: Scheduler,
+    ) -> None:
         self.model = model
         self.legalized_model = None
         self.criterion = criterion
@@ -187,44 +190,52 @@ class ParamsShiftTrainer(Trainer):
     def set_use_qiskit(self, configs):
         self.use_qiskit_train = configs.qiskit.use_qiskit_train
         self.use_qiskit_valid = configs.qiskit.use_qiskit_valid
-    
+
     def _before_epoch(self) -> None:
         self.model.train()
         self.is_training = True
 
-    def run_step(self, feed_dict: Dict[str, Any], legalize=False) -> Dict[
-            str, Any]:
-        if self.profile_shots and self.global_step % self.per_steps == 0 and self.is_training:
+    def run_step(self, feed_dict: Dict[str, Any], legalize=False) -> Dict[str, Any]:
+        if (
+            self.profile_shots
+            and self.global_step % self.per_steps == 0
+            and self.is_training
+        ):
             self.record[self.global_step] = {}
             for i in range(4):
                 for shots, processor in self.processor_list:
                     self.model.set_qiskit_processor(processor)
-                    self.record[self.global_step][i] = self._get_grad(feed_dict, use_qiskit=True)
+                    self.record[self.global_step][i] = self._get_grad(
+                        feed_dict, use_qiskit=True
+                    )
             output_dict = self._run_params_shift_step(feed_dict, use_qiskit=False)
             grad_list = []
             for param in self.model.parameters():
                 grad_list.append(param.grad.item())
-            self.record[self.global_step]['classical'] = grad_list
+            self.record[self.global_step]["classical"] = grad_list
 
             return output_dict
-        
+
         if self.is_training:
-            output_dict = self._run_params_shift_step(feed_dict, use_qiskit=self.use_qiskit_train)
+            output_dict = self._run_params_shift_step(
+                feed_dict, use_qiskit=self.use_qiskit_train
+            )
         else:
-            output_dict = self._run_step(feed_dict, legalize=legalize, use_qiskit=self.use_qiskit_valid)
+            output_dict = self._run_step(
+                feed_dict, legalize=legalize, use_qiskit=self.use_qiskit_valid
+            )
         return output_dict
 
-    def _run_params_shift_step(self, feed_dict: Dict[str, Any], use_qiskit=False) -> Dict[
-            str, Any]:
-        if configs.run.device == 'gpu':
-            inputs = feed_dict[configs.dataset.input_name].cuda(
-                non_blocking=True)
-            targets = feed_dict[configs.dataset.target_name].cuda(
-                non_blocking=True)
+    def _run_params_shift_step(
+        self, feed_dict: Dict[str, Any], use_qiskit=False
+    ) -> Dict[str, Any]:
+        if configs.run.device == "gpu":
+            inputs = feed_dict[configs.dataset.input_name].cuda(non_blocking=True)
+            targets = feed_dict[configs.dataset.target_name].cuda(non_blocking=True)
         else:
             inputs = feed_dict[configs.dataset.input_name]
             targets = feed_dict[configs.dataset.target_name]
-        
+
         # print('bp:')
         # outputs = self.model(inputs)
         # loss = self.criterion(outputs, targets)
@@ -235,46 +246,57 @@ class ParamsShiftTrainer(Trainer):
 
         outputs = None
         if self.global_step > self.work_from_step:
-            outputs = self.model.shift_and_run(inputs, self.global_step,
-                self.steps_per_epoch * self.num_epochs, verbose=False, use_qiskit=use_qiskit)
+            outputs = self.model.shift_and_run(
+                inputs,
+                self.global_step,
+                self.steps_per_epoch * self.num_epochs,
+                verbose=False,
+                use_qiskit=use_qiskit,
+            )
         else:
-            logger.info('global_step {0}, skip parameters shift.'.format(self.global_step))
+            logger.info(
+                "global_step {0}, skip parameters shift.".format(self.global_step)
+            )
             outputs = self.model(inputs, False, use_qiskit=use_qiskit)
         loss = self.criterion(outputs, targets)
         nll_loss = loss.item()
 
         for k, group in enumerate(self.optimizer.param_groups):
-            self.summary.add_scalar(f'lr/lr_group{k}', group['lr'])
-        self.summary.add_scalar('loss', loss.item())
-        self.summary.add_scalar('nll_loss', nll_loss)
+            self.summary.add_scalar(f"lr/lr_group{k}", group["lr"])
+        self.summary.add_scalar("loss", loss.item())
+        self.summary.add_scalar("nll_loss", nll_loss)
 
         if self.global_step > self.work_from_step:
             self.optimizer.zero_grad()
             loss.backward()
             self.model.backprop_grad()
         else:
-            logger.info('global_step {0}, load grad from tensorboard file!'.format(self.global_step))
+            logger.info(
+                "global_step {0}, load grad from tensorboard file!".format(
+                    self.global_step
+                )
+            )
             for i, param in enumerate(self.model.parameters()):
-                param.grad = torch.tensor(self.grad_dict[self.global_step][i]).to(dtype=torch.float32, device=param.device).view(param.shape)
+                param.grad = (
+                    torch.tensor(self.grad_dict[self.global_step][i])
+                    .to(dtype=torch.float32, device=param.device)
+                    .view(param.shape)
+                )
         # print('ps:')
         # for param in self.model.parameters():
         #     print(param.grad)
         self.optimizer.step()
 
-        return {'outputs': outputs, 'targets': targets}
+        return {"outputs": outputs, "targets": targets}
 
-
-    def _get_grad(self, feed_dict: Dict[str, Any], use_qiskit=False) -> Dict[
-            str, Any]:
-        if configs.run.device == 'gpu':
-            inputs = feed_dict[configs.dataset.input_name].cuda(
-                non_blocking=True)
-            targets = feed_dict[configs.dataset.target_name].cuda(
-                non_blocking=True)
+    def _get_grad(self, feed_dict: Dict[str, Any], use_qiskit=False) -> Dict[str, Any]:
+        if configs.run.device == "gpu":
+            inputs = feed_dict[configs.dataset.input_name].cuda(non_blocking=True)
+            targets = feed_dict[configs.dataset.target_name].cuda(non_blocking=True)
         else:
             inputs = feed_dict[configs.dataset.input_name]
             targets = feed_dict[configs.dataset.target_name]
-        
+
         # outputs = self.model(inputs)
         # loss = self.criterion(outputs, targets)
         # self.optimizer.zero_grad()
@@ -284,27 +306,42 @@ class ParamsShiftTrainer(Trainer):
 
         outputs = None
         if self.global_step > self.work_from_step:
-            outputs = self.model.shift_and_run(inputs, self.global_step,
-                self.steps_per_epoch * self.num_epochs, verbose=False, use_qiskit=use_qiskit)
+            outputs = self.model.shift_and_run(
+                inputs,
+                self.global_step,
+                self.steps_per_epoch * self.num_epochs,
+                verbose=False,
+                use_qiskit=use_qiskit,
+            )
         else:
-            logger.info('global_step {0}, skip parameters shift.'.format(self.global_step))
+            logger.info(
+                "global_step {0}, skip parameters shift.".format(self.global_step)
+            )
             outputs = self.model(inputs, False, use_qiskit)
         loss = self.criterion(outputs, targets)
         nll_loss = loss.item()
 
         for k, group in enumerate(self.optimizer.param_groups):
-            self.summary.add_scalar(f'lr/lr_group{k}', group['lr'])
-        self.summary.add_scalar('loss', loss.item())
-        self.summary.add_scalar('nll_loss', nll_loss)
+            self.summary.add_scalar(f"lr/lr_group{k}", group["lr"])
+        self.summary.add_scalar("loss", loss.item())
+        self.summary.add_scalar("nll_loss", nll_loss)
 
         self.optimizer.zero_grad()
         loss.backward()
         if self.global_step > self.work_from_step:
             self.model.backprop_grad()
         else:
-            logger.info('global_step {0}, load grad from tensorboard file!'.format(self.global_step))
+            logger.info(
+                "global_step {0}, load grad from tensorboard file!".format(
+                    self.global_step
+                )
+            )
             for i, param in enumerate(self.model.parameters()):
-                param.grad = torch.tensor(self.grad_dict[self.global_step][i]).to(dtype=torch.float32, device=param.device).view(param.shape)
+                param.grad = (
+                    torch.tensor(self.grad_dict[self.global_step][i])
+                    .to(dtype=torch.float32, device=param.device)
+                    .view(param.shape)
+                )
         grad_list = []
         for param in self.model.parameters():
             grad_list.append(param.grad.item())
@@ -315,15 +352,12 @@ class ParamsShiftTrainer(Trainer):
 
         return grad_list
 
-
-
-    def _run_step(self, feed_dict: Dict[str, Any], legalize=False, use_qiskit=False) -> Dict[
-            str, Any]:
-        if configs.run.device == 'gpu':
-            inputs = feed_dict[configs.dataset.input_name].cuda(
-                non_blocking=True)
-            targets = feed_dict[configs.dataset.target_name].cuda(
-                non_blocking=True)
+    def _run_step(
+        self, feed_dict: Dict[str, Any], legalize=False, use_qiskit=False
+    ) -> Dict[str, Any]:
+        if configs.run.device == "gpu":
+            inputs = feed_dict[configs.dataset.input_name].cuda(non_blocking=True)
+            targets = feed_dict[configs.dataset.target_name].cuda(non_blocking=True)
         else:
             inputs = feed_dict[configs.dataset.input_name]
             targets = feed_dict[configs.dataset.target_name]
@@ -336,32 +370,32 @@ class ParamsShiftTrainer(Trainer):
 
         if loss.requires_grad:
             for k, group in enumerate(self.optimizer.param_groups):
-                self.summary.add_scalar(f'lr/lr_group{k}', group['lr'])
-            self.summary.add_scalar('loss', loss.item())
-            self.summary.add_scalar('nll_loss', nll_loss)
-            if getattr(self.model, 'sample_arch', None) is not None:
+                self.summary.add_scalar(f"lr/lr_group{k}", group["lr"])
+            self.summary.add_scalar("loss", loss.item())
+            self.summary.add_scalar("nll_loss", nll_loss)
+            if getattr(self.model, "sample_arch", None) is not None:
                 for writer in self.summary.writers:
                     if isinstance(writer, TFEventWriter):
                         writer.writer.add_text(
-                            'sample_arch', str(self.model.sample_arch),
-                            self.global_step)
+                            "sample_arch", str(self.model.sample_arch), self.global_step
+                        )
 
             if configs.regularization.unitary_loss:
                 if configs.regularization.unitary_loss_lambda_trainable:
                     self.summary.add_scalar(
-                        'u_loss_lambda',
-                        self.model.unitary_loss_lambda.item())
+                        "u_loss_lambda", self.model.unitary_loss_lambda.item()
+                    )
                 else:
                     self.summary.add_scalar(
-                        'u_loss_lambda',
-                        configs.regularization.unitary_loss_lambda)
-                self.summary.add_scalar('u_loss', unitary_loss.item())
+                        "u_loss_lambda", configs.regularization.unitary_loss_lambda
+                    )
+                self.summary.add_scalar("u_loss", unitary_loss.item())
 
             self.optimizer.zero_grad()
             loss.backward()
             self.optimizer.step()
 
-        return {'outputs': outputs, 'targets': targets}
+        return {"outputs": outputs, "targets": targets}
 
     def _after_epoch(self) -> None:
         self.model.eval()
@@ -372,7 +406,7 @@ class ParamsShiftTrainer(Trainer):
         #         legalize_unitary(self.model)
         self.save_global_step = self.global_step
         self.global_step = int(self.model.num_forwards)
-    
+
     def _trigger_epoch(self) -> None:
         self.global_step = self.save_global_step
 
@@ -386,42 +420,40 @@ class ParamsShiftTrainer(Trainer):
         state_dict = dict()
         # need to store model arch because of randomness of random layers
         # state_dict['model_arch'] = self.model
-        state_dict['model'] = self.model.state_dict()
-        state_dict['optimizer'] = self.optimizer.state_dict()
-        state_dict['scheduler'] = self.scheduler.state_dict()
-        if getattr(self.model, 'sample_arch', None) is not None:
-            state_dict['sample_arch'] = self.model.sample_arch
+        state_dict["model"] = self.model.state_dict()
+        state_dict["optimizer"] = self.optimizer.state_dict()
+        state_dict["scheduler"] = self.scheduler.state_dict()
+        if getattr(self.model, "sample_arch", None) is not None:
+            state_dict["sample_arch"] = self.model.sample_arch
 
         if self.solution is not None:
-            state_dict['solution'] = self.solution
-            state_dict['score'] = self.score
+            state_dict["solution"] = self.solution
+            state_dict["score"] = self.score
 
-        if getattr(self.model, 'encoder', None) is not None:
-            if getattr(self.model.encoder, 'func_list', None) is not None:
-                state_dict['encoder_func_list'] = self.model.encoder.func_list
+        if getattr(self.model, "encoder", None) is not None:
+            if getattr(self.model.encoder, "func_list", None) is not None:
+                state_dict["encoder_func_list"] = self.model.encoder.func_list
 
-        if getattr(self.model, 'q_layer', None) is not None:
-            state_dict['q_layer_op_list'] = build_module_op_list(
-                self.model.q_layer)
+        if getattr(self.model, "q_layer", None) is not None:
+            state_dict["q_layer_op_list"] = build_module_op_list(self.model.q_layer)
 
-        if getattr(self.model, 'measure', None) is not None:
-            if getattr(self.model.measure,
-                       'v_c_reg_mapping', None) is not None:
-                state_dict['v_c_reg_mapping'] = \
-                    self.model.measure.v_c_reg_mapping
+        if getattr(self.model, "measure", None) is not None:
+            if getattr(self.model.measure, "v_c_reg_mapping", None) is not None:
+                state_dict["v_c_reg_mapping"] = self.model.measure.v_c_reg_mapping
 
-        if getattr(self.model, 'nodes', None) is not None:
-            state_dict['encoder_func_list'] = [
-                node.encoder.func_list for node in self.model.nodes]
+        if getattr(self.model, "nodes", None) is not None:
+            state_dict["encoder_func_list"] = [
+                node.encoder.func_list for node in self.model.nodes
+            ]
             if configs.model.transpile_before_run:
                 # only save op_list if transpile before run
-                state_dict['q_layer_op_list'] = [
-                    build_module_op_list(node.q_layer) for node in
-                    self.model.nodes]
-            state_dict['v_c_reg_mapping'] = [
-                node.measure.v_c_reg_mapping for node in self.model.nodes]
-        for attr in ['v_c_reg_mapping', 'encoder_func_list',
-                     'q_layer_op_list']:
+                state_dict["q_layer_op_list"] = [
+                    build_module_op_list(node.q_layer) for node in self.model.nodes
+                ]
+            state_dict["v_c_reg_mapping"] = [
+                node.measure.v_c_reg_mapping for node in self.model.nodes
+            ]
+        for attr in ["v_c_reg_mapping", "encoder_func_list", "q_layer_op_list"]:
             if state_dict.get(attr, None) is None:
                 logger.warning(f"No {attr} found, will not save it.")
 
@@ -429,14 +461,18 @@ class ParamsShiftTrainer(Trainer):
 
     def _load_state_dict(self, state_dict: Dict[str, Any]) -> None:
         # self.model.load_state_dict(state_dict['model'])
-        self.optimizer.load_state_dict(state_dict['optimizer'])
-        self.scheduler.load_state_dict(state_dict['scheduler'])
+        self.optimizer.load_state_dict(state_dict["optimizer"])
+        self.scheduler.load_state_dict(state_dict["scheduler"])
 
     def update_accuracy(self, name, accuracy):
-        if name == 'acc/test':
+        if name == "acc/test":
             self.global_epoch += 1
             if accuracy > self.max_acc:
                 self.max_acc = accuracy
                 self.max_acc_epoch = self.global_epoch
             elif self.global_epoch - self.max_acc_epoch >= 50:
-                raise StopTraining('Early stop at epoch{0}, num inferences = {1}, global_step={2}'.format(self.global_epoch, self.global_step, self.save_global_step))
+                raise StopTraining(
+                    "Early stop at epoch{0}, num inferences = {1}, global_step={2}".format(
+                        self.global_epoch, self.global_step, self.save_global_step
+                    )
+                )
