@@ -2,7 +2,7 @@ from torchpack.datasets.dataset import Dataset
 import numpy as np
 import torch
 
-__all__ = ['LayerRegression']
+__all__ = ["LayerRegression"]
 
 
 class LayerRegressionDatasetV:
@@ -13,8 +13,7 @@ class LayerRegressionDatasetV:
         self.output = np.random.rand(5).astype(np.float) * 2 - 1
 
     def __getitem__(self, index: int):
-        instance = {'input': self.input,
-                    'output': self.output}
+        instance = {"input": self.input, "output": self.output}
         return instance
 
     def __len__(self) -> int:
@@ -22,25 +21,25 @@ class LayerRegressionDatasetV:
 
 
 class LayerRegressionV(Dataset):
-    def __init__(self,):
-        super().__init__({
-            split: LayerRegressionDatasetV()
-            for split in ['train', 'valid', 'test']
-        })
+    def __init__(
+        self,
+    ):
+        super().__init__(
+            {split: LayerRegressionDatasetV() for split in ["train", "valid", "test"]}
+        )
 
 
 class LayerRegressionDataset:
     def __init__(self):
         self.data = None
         self.n_instance = 10000
-        mat = torch.randn((2 ** 5, 2 ** 5), dtype=torch.complex64)
+        mat = torch.randn((2**5, 2**5), dtype=torch.complex64)
         mat = mat.svd()[0].data
 
         self.output = mat
 
     def __getitem__(self, index: int):
-        instance = {'input': self.output,
-                    'output': self.output}
+        instance = {"input": self.output, "output": self.output}
         return instance
 
     def __len__(self) -> int:
@@ -48,8 +47,9 @@ class LayerRegressionDataset:
 
 
 class LayerRegression(Dataset):
-    def __init__(self,):
-        super().__init__({
-            split: LayerRegressionDataset()
-            for split in ['train', 'valid', 'test']
-        })
\ No newline at end of file
+    def __init__(
+        self,
+    ):
+        super().__init__(
+            {split: LayerRegressionDataset() for split in ["train", "valid", "test"]}
+        )
