@@ -9,22 +9,22 @@ from torchquantum.plugins.qiskit_macros import QISKIT_INCOMPATIBLE_FUNC_NAMES
 from torchpack.utils.logging import logger
 
 __all__ = [
-    'QuantumModuleFromOps',
-    'TrainableOpAll',
-    'ClassicalInOpAll',
-    'FixedOpAll',
-    'TwoQAll',
-    'RandomLayer',
-    'RandomLayerAllTypes',
-    'Op1QAllLayer',
-    'Op2QAllLayer',
-    'Op2QButterflyLayer',
-    'Op2QDenseLayer',
-    'layer_name_dict',
-    'CXLayer',
-    'CXCXCXLayer',
-    'SWAPSWAPLayer',
-    'RXYZCXLayer0',
+    "QuantumModuleFromOps",
+    "TrainableOpAll",
+    "ClassicalInOpAll",
+    "FixedOpAll",
+    "TwoQAll",
+    "RandomLayer",
+    "RandomLayerAllTypes",
+    "Op1QAllLayer",
+    "Op2QAllLayer",
+    "Op2QButterflyLayer",
+    "Op2QDenseLayer",
+    "layer_name_dict",
+    "CXLayer",
+    "CXCXCXLayer",
+    "SWAPSWAPLayer",
+    "RXYZCXLayer0",
 ]
 
 
@@ -46,22 +46,22 @@ class TrainableOpAll(tq.QuantumModule):
     One potential optimization is to compute the unitary of all gates
     together.
     """
+
     def __init__(self, n_gate: int, op: tq.Operation):
         super().__init__()
         self.n_gate = n_gate
         self.gate_all = nn.ModuleList()
         for k in range(self.n_gate):
-            self.gate_all.append(op(
-                has_params=True,
-                trainable=True))
+            self.gate_all.append(op(has_params=True, trainable=True))
 
     @tq.static_support
     def forward(self, q_device: tq.QuantumDevice):
         # rx on all wires, assert the number of gate is the same as the number
         # of wires in the device.
-        assert self.n_gate == q_device.n_wires, \
-            f"Number of rx gates ({self.n_gate}) is different from number " \
+        assert self.n_gate == q_device.n_wires, (
+            f"Number of rx gates ({self.n_gate}) is different from number "
             f"of wires ({q_device.n_wires})!"
+        )
 
         for k in range(self.n_gate):
             self.gate_all[k](q_device, wires=k)
@@ -79,9 +79,10 @@ class ClassicalInOpAll(tq.QuantumModule):
     def forward(self, q_device: tq.QuantumDevice, x):
         # rx on all wires, assert the number of gate is the same as the number
         # of wires in the device.
-        assert self.n_gate == q_device.n_wires, \
-            f"Number of rx gates ({self.n_gate}) is different from number " \
+        assert self.n_gate == q_device.n_wires, (
+            f"Number of rx gates ({self.n_gate}) is different from number "
             f"of wires ({q_device.n_wires})!"
+        )
 
         for k in range(self.n_gate):
             self.gate_all[k](q_device, wires=k, params=x[:, k])
@@ -99,9 +100,10 @@ class FixedOpAll(tq.QuantumModule):
     def forward(self, q_device: tq.QuantumDevice):
         # rx on all wires, assert the number of gate is the same as the number
         # of wires in the device.
-        assert self.n_gate == q_device.n_wires, \
-            f"Number of rx gates ({self.n_gate}) is different from number " \
+        assert self.n_gate == q_device.n_wires, (
+            f"Number of rx gates ({self.n_gate}) is different from number "
             f"of wires ({q_device.n_wires})!"
+        )
 
         for k in range(self.n_gate):
             self.gate_all[k](q_device, wires=k)
@@ -115,21 +117,22 @@ class TwoQAll(tq.QuantumModule):
 
     @tq.static_support
     def forward(self, q_device: tq.QuantumDevice):
-        for k in range(self.n_gate-1):
+        for k in range(self.n_gate - 1):
             self.op(q_device, wires=[k, k + 1])
-        self.op(q_device, wires=[self.n_gate-1, 0])
+        self.op(q_device, wires=[self.n_gate - 1, 0])
 
 
 class RandomLayer(tq.QuantumModule):
-    def __init__(self,
-                 wires,
-                 n_ops=None,
-                 n_params=None,
-                 op_ratios=None,
-                 op_types=(tq.RX, tq.RY, tq.RZ, tq.CNOT),
-                 seed=None,
-                 qiskit_compatible=False,
-                 ):
+    def __init__(
+        self,
+        wires,
+        n_ops=None,
+        n_params=None,
+        op_ratios=None,
+        op_types=(tq.RX, tq.RY, tq.RZ, tq.CNOT),
+        seed=None,
+        qiskit_compatible=False,
+    ):
         super().__init__()
         self.n_ops = n_ops
         self.n_params = n_params
@@ -141,16 +144,17 @@ class RandomLayer(tq.QuantumModule):
         if op_ratios is None:
             op_ratios = [1] * len(op_types)
         else:
-            op_ratios = op_ratios if isinstance(op_ratios, Iterable) else [
-                op_ratios]
+            op_ratios = op_ratios if isinstance(op_ratios, Iterable) else [op_ratios]
         op_types_valid = []
         op_ratios_valid = []
 
         if qiskit_compatible:
             for op_type, op_ratio in zip(op_types, op_ratios):
                 if op_type().name.lower() in QISKIT_INCOMPATIBLE_FUNC_NAMES:
-                    logger.warning(f"Remove {op_type} from op_types to make "
-                                   f"the layer qiskit-compatible.")
+                    logger.warning(
+                        f"Remove {op_type} from op_types to make "
+                        f"the layer qiskit-compatible."
+                    )
                 else:
                     op_types_valid.append(op_type)
                     op_ratios_valid.append(op_ratio)
@@ -167,10 +171,7 @@ class RandomLayer(tq.QuantumModule):
             np.random.seed(seed)
         self.build_random_layer()
 
-    def rebuild_random_layer_from_op_list(self,
-                                          n_ops_in,
-                                          wires_in,
-                                          op_list_in):
+    def rebuild_random_layer_from_op_list(self, n_ops_in, wires_in, op_list_in):
         """Used for loading random layer from checkpoint"""
         self.n_ops = n_ops_in
         self.wires = wires_in
@@ -198,12 +199,17 @@ class RandomLayer(tq.QuantumModule):
             else:
                 is_AnyWire = False
 
-            op_wires = list(np.random.choice(self.wires, size=n_op_wires,
-                                             replace=False))
+            op_wires = list(
+                np.random.choice(self.wires, size=n_op_wires, replace=False)
+            )
             if is_AnyWire:
-                if op().name in ['MultiRZ']:
-                    operation = op(has_params=True, trainable=True,
-                                   n_wires=n_op_wires, wires=op_wires)
+                if op().name in ["MultiRZ"]:
+                    operation = op(
+                        has_params=True,
+                        trainable=True,
+                        n_wires=n_op_wires,
+                        wires=op_wires,
+                    )
                 else:
                     operation = op(n_wires=n_op_wires, wires=op_wires)
             elif op().name in tq.Operator.parameterized_ops:
@@ -221,8 +227,8 @@ class RandomLayer(tq.QuantumModule):
                     break
                 elif param_cnt > self.n_params:
                     """
-                    the last operation has too many params and exceed the 
-                    constraint, so need to remove it and sample another 
+                    the last operation has too many params and exceed the
+                    constraint, so need to remove it and sample another
                     """
                     op_cnt -= 1
                     param_cnt -= op.num_params
@@ -230,51 +236,52 @@ class RandomLayer(tq.QuantumModule):
 
     @tq.static_support
     def forward(self, q_device: tq.QuantumDevice):
-        self.q_device = q_device
         for op in self.op_list:
             op(q_device)
 
 
 class RandomLayerAllTypes(RandomLayer):
-    def __init__(self,
-                 wires,
-                 n_ops=None,
-                 n_params=None,
-                 op_ratios=None,
-                 op_types=(tq.Hadamard,
-                           tq.SHadamard,
-                           tq.PauliX,
-                           tq.PauliY,
-                           tq.PauliZ,
-                           tq.S,
-                           tq.T,
-                           tq.SX,
-                           tq.CNOT,
-                           tq.CZ,
-                           tq.CY,
-                           tq.RX,
-                           tq.RY,
-                           tq.RZ,
-                           tq.RZZ,
-                           tq.SWAP,
-                           tq.CSWAP,
-                           tq.Toffoli,
-                           tq.PhaseShift,
-                           tq.Rot,
-                           tq.MultiRZ,
-                           tq.CRX,
-                           tq.CRY,
-                           tq.CRZ,
-                           tq.CRot,
-                           tq.U1,
-                           tq.U2,
-                           tq.U3,
-                           tq.MultiCNOT,
-                           tq.MultiXCNOT,
-                           ),
-                 seed=None,
-                 qiskit_compatible=False,
-                 ):
+    def __init__(
+        self,
+        wires,
+        n_ops=None,
+        n_params=None,
+        op_ratios=None,
+        op_types=(
+            tq.Hadamard,
+            tq.SHadamard,
+            tq.PauliX,
+            tq.PauliY,
+            tq.PauliZ,
+            tq.S,
+            tq.T,
+            tq.SX,
+            tq.CNOT,
+            tq.CZ,
+            tq.CY,
+            tq.RX,
+            tq.RY,
+            tq.RZ,
+            tq.RZZ,
+            tq.SWAP,
+            tq.CSWAP,
+            tq.Toffoli,
+            tq.PhaseShift,
+            tq.Rot,
+            tq.MultiRZ,
+            tq.CRX,
+            tq.CRY,
+            tq.CRZ,
+            tq.CRot,
+            tq.U1,
+            tq.U2,
+            tq.U3,
+            tq.MultiCNOT,
+            tq.MultiXCNOT,
+        ),
+        seed=None,
+        qiskit_compatible=False,
+    ):
         super().__init__(
             wires=wires,
             n_ops=n_ops,
@@ -297,13 +304,12 @@ class SimpleQLayer(tq.QuantumModule):
     @tq.static_support
     def forward(self, q_dev):
         self.q_device = q_dev
-        tqf.x(q_dev, wires=0, static=self.static_mode,
-              parent_graph=self.graph)
+        tqf.x(q_dev, wires=0, static=self.static_mode, parent_graph=self.graph)
         self.gate1(q_dev, wires=1)
         self.gate2(q_dev, wires=1)
         self.gate3(q_dev, wires=1)
-        tqf.x(q_dev, wires=2, static=self.static_mode,
-              parent_graph=self.graph)
+        tqf.x(q_dev, wires=2, static=self.static_mode, parent_graph=self.graph)
+
 
 class CXLayer(tq.QuantumModule):
     def __init__(self, n_wires):
@@ -313,8 +319,7 @@ class CXLayer(tq.QuantumModule):
     @tq.static_support
     def forward(self, q_dev):
         self.q_device = q_dev
-        tqf.cnot(q_dev, wires=[0, 1], static=self.static_mode,
-              parent_graph=self.graph)
+        tqf.cnot(q_dev, wires=[0, 1], static=self.static_mode, parent_graph=self.graph)
 
 
 class CXCXCXLayer(tq.QuantumModule):
@@ -325,13 +330,9 @@ class CXCXCXLayer(tq.QuantumModule):
     @tq.static_support
     def forward(self, q_dev):
         self.q_device = q_dev
-        tqf.cnot(q_dev, wires=[0, 1], static=self.static_mode,
-              parent_graph=self.graph)
-        tqf.cnot(q_dev, wires=[1, 2], static=self.static_mode,
-              parent_graph=self.graph)
-        tqf.cnot(q_dev, wires=[2, 0], static=self.static_mode,
-              parent_graph=self.graph)
-
+        tqf.cnot(q_dev, wires=[0, 1], static=self.static_mode, parent_graph=self.graph)
+        tqf.cnot(q_dev, wires=[1, 2], static=self.static_mode, parent_graph=self.graph)
+        tqf.cnot(q_dev, wires=[2, 0], static=self.static_mode, parent_graph=self.graph)
 
 
 class SWAPSWAPLayer(tq.QuantumModule):
@@ -342,10 +343,8 @@ class SWAPSWAPLayer(tq.QuantumModule):
     @tq.static_support
     def forward(self, q_dev):
         self.q_device = q_dev
-        tqf.swap(q_dev, wires=[0, 1], static=self.static_mode,
-              parent_graph=self.graph)
-        tqf.swap(q_dev, wires=[1, 2], static=self.static_mode,
-              parent_graph=self.graph)
+        tqf.swap(q_dev, wires=[0, 1], static=self.static_mode, parent_graph=self.graph)
+        tqf.swap(q_dev, wires=[1, 2], static=self.static_mode, parent_graph=self.graph)
 
 
 class Op1QAllLayer(tq.QuantumModule):
@@ -355,8 +354,7 @@ class Op1QAllLayer(tq.QuantumModule):
         self.op = op
         self.ops_all = tq.QuantumModuleList()
         for k in range(n_wires):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
@@ -380,8 +378,17 @@ class Op2QAllLayer(tq.QuantumModule):
     jump = 4: [0, 4], [1, 5], [2, 0], [3, 1], [4, 2], [5, 3]
     jump = 5: [0, 5], [1, 0], [2, 1], [3, 2], [4, 3], [5, 4]
     """
-    def __init__(self, op, n_wires: int, has_params=False, trainable=False,
-                 wire_reverse=False, jump=1, circular=False):
+
+    def __init__(
+        self,
+        op,
+        n_wires: int,
+        has_params=False,
+        trainable=False,
+        wire_reverse=False,
+        jump=1,
+        circular=False,
+    ):
         super().__init__()
         self.n_wires = n_wires
         self.jump = jump
@@ -397,8 +404,7 @@ class Op2QAllLayer(tq.QuantumModule):
         else:
             n_ops = n_wires - jump
         for k in range(n_ops):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
@@ -408,9 +414,18 @@ class Op2QAllLayer(tq.QuantumModule):
                 wires.reverse()
             self.ops_all[k](q_device, wires=wires)
 
+
 class Op2QFit32Layer(tq.QuantumModule):
-    def __init__(self, op, n_wires: int, has_params=False, trainable=False,
-                 wire_reverse=False, jump=1, circular=False):
+    def __init__(
+        self,
+        op,
+        n_wires: int,
+        has_params=False,
+        trainable=False,
+        wire_reverse=False,
+        jump=1,
+        circular=False,
+    ):
         super().__init__()
         self.n_wires = n_wires
         self.jump = jump
@@ -427,8 +442,7 @@ class Op2QFit32Layer(tq.QuantumModule):
         #     n_ops = n_wires - jump
         n_ops = 32
         for k in range(n_ops):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
@@ -440,10 +454,11 @@ class Op2QFit32Layer(tq.QuantumModule):
 
 
 class Op2QButterflyLayer(tq.QuantumModule):
-    """pattern: [0, 5], [1, 4], [2, 3]
-    """
-    def __init__(self, op, n_wires: int, has_params=False, trainable=False,
-                 wire_reverse=False):
+    """pattern: [0, 5], [1, 4], [2, 3]"""
+
+    def __init__(
+        self, op, n_wires: int, has_params=False, trainable=False, wire_reverse=False
+    ):
         super().__init__()
         self.n_wires = n_wires
         self.op = op
@@ -453,8 +468,7 @@ class Op2QButterflyLayer(tq.QuantumModule):
         self.wire_reverse = wire_reverse
 
         for k in range(n_wires // 2):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     def forward(self, q_device):
         for k in range(len(self.ops_all)):
@@ -472,8 +486,10 @@ class Op2QDenseLayer(tq.QuantumModule):
     [3, 4], [3, 5]
     [4, 5]
     """
-    def __init__(self, op, n_wires: int, has_params=False, trainable=False,
-                 wire_reverse=False):
+
+    def __init__(
+        self, op, n_wires: int, has_params=False, trainable=False, wire_reverse=False
+    ):
         super().__init__()
         self.n_wires = n_wires
         self.op = op
@@ -483,8 +499,7 @@ class Op2QDenseLayer(tq.QuantumModule):
         self.wire_reverse = wire_reverse
 
         for k in range(self.n_wires * (self.n_wires - 1) // 2):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     def forward(self, q_device):
         k = 0
@@ -500,11 +515,11 @@ class Op2QDenseLayer(tq.QuantumModule):
 class LayerTemplate0(tq.QuantumModule):
     def __init__(self, arch: dict = None):
         super().__init__()
-        self.n_wires = arch['n_wires']
+        self.n_wires = arch["n_wires"]
         self.arch = arch
 
-        self.n_blocks = arch.get('n_blocks', None)
-        self.n_layers_per_block = arch.get('n_layers_per_block', None)
+        self.n_blocks = arch.get("n_blocks", None)
+        self.n_layers_per_block = arch.get("n_layers_per_block", None)
 
         self.layers_all = self.build_layers()
 
@@ -520,15 +535,15 @@ class LayerTemplate0(tq.QuantumModule):
 
 class U3CU3Layer0(LayerTemplate0):
     """u3 cu3 blocks"""
+
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.U3,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.U3, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(
                 Op2QAllLayer(
                     op=tq.CU3,
@@ -536,15 +551,18 @@ class U3CU3Layer0(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return layers_all
 
 
 class CU3Layer0(LayerTemplate0):
     """u3 cu3 blocks"""
+
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op2QAllLayer(
                     op=tq.CU3,
@@ -552,53 +570,49 @@ class CU3Layer0(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=False))
+                    circular=False,
+                )
+            )
         return layers_all
 
 
 class CXRZSXLayer0(LayerTemplate0):
     """CXRZSX blocks"""
+
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
 
         layers_all.append(
             Op1QAllLayer(
-                op=tq.RZ,
-                n_wires=self.n_wires,
-                has_params=True,
-                trainable=True))
+                op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+            )
+        )
         layers_all.append(
-            Op2QAllLayer(
-                op=tq.CNOT,
-                n_wires=self.n_wires,
-                jump=1,
-                circular=False))
-        for k in range(self.arch['n_blocks']):
+            Op2QAllLayer(op=tq.CNOT, n_wires=self.n_wires, jump=1, circular=False)
+        )
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RZ,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.SX,
-                    n_wires=self.n_wires,
-                    has_params=False,
-                    trainable=False))
+                    op=tq.SX, n_wires=self.n_wires, has_params=False, trainable=False
+                )
+            )
         layers_all.append(
             Op1QAllLayer(
-                op=tq.RZ,
-                n_wires=self.n_wires,
-                has_params=True,
-                trainable=True))
+                op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+            )
+        )
         return layers_all
 
 
 class SethLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op2QAllLayer(
                     op=tq.RZZ,
@@ -606,20 +620,21 @@ class SethLayer0(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
         return layers_all
 
 
 class SethLayer1(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op2QAllLayer(
                     op=tq.RZZ,
@@ -627,13 +642,14 @@ class SethLayer1(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(
                 Op2QAllLayer(
                     op=tq.RZZ,
@@ -641,14 +657,16 @@ class SethLayer1(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return layers_all
 
 
 class SethLayer2(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op2QFit32Layer(
                     op=tq.RZZ,
@@ -656,14 +674,16 @@ class SethLayer2(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return layers_all
 
 
 class RZZLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op2QAllLayer(
                     op=tq.RZZ,
@@ -671,7 +691,9 @@ class RZZLayer0(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return layers_all
 
 
@@ -681,39 +703,33 @@ class BarrenLayer0(LayerTemplate0):
         layers_all.append(
             Op1QAllLayer(
                 op=tq.SHadamard,
-                n_wires=self.n_wires,)
+                n_wires=self.n_wires,
+            )
         )
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RX,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RX, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RZ,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
-            layers_all.append(
-                Op2QAllLayer(
-                    op=tq.CZ,
-                    n_wires=self.n_wires,
-                    jump=1))
+                    op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
+            layers_all.append(Op2QAllLayer(op=tq.CZ, n_wires=self.n_wires, jump=1))
         return layers_all
 
 
 class FarhiLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op2QAllLayer(
                     op=tq.RZX,
@@ -721,7 +737,9 @@ class FarhiLayer0(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
             layers_all.append(
                 Op2QAllLayer(
                     op=tq.RXX,
@@ -729,72 +747,51 @@ class FarhiLayer0(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return layers_all
 
 
 class MaxwellLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RX,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RX, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
+            layers_all.append(Op1QAllLayer(op=tq.S, n_wires=self.n_wires))
             layers_all.append(
-                Op1QAllLayer(
-                    op=tq.S,
-                    n_wires=self.n_wires))
-            layers_all.append(
-                Op2QAllLayer(
-                    op=tq.CNOT,
-                    n_wires=self.n_wires,
-                    jump=1,
-                    circular=True))
+                Op2QAllLayer(op=tq.CNOT, n_wires=self.n_wires, jump=1, circular=True)
+            )
 
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
+            layers_all.append(Op1QAllLayer(op=tq.T, n_wires=self.n_wires))
             layers_all.append(
-                Op1QAllLayer(
-                    op=tq.T,
-                    n_wires=self.n_wires))
-            layers_all.append(
-                Op2QAllLayer(
-                    op=tq.SWAP,
-                    n_wires=self.n_wires,
-                    jump=1,
-                    circular=True))
+                Op2QAllLayer(op=tq.SWAP, n_wires=self.n_wires, jump=1, circular=True)
+            )
 
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RZ,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
+            layers_all.append(Op1QAllLayer(op=tq.Hadamard, n_wires=self.n_wires))
             layers_all.append(
-                Op1QAllLayer(
-                    op=tq.Hadamard,
-                    n_wires=self.n_wires))
-            layers_all.append(
-                Op2QAllLayer(
-                    op=tq.SSWAP,
-                    n_wires=self.n_wires,
-                    jump=1,
-                    circular=True))
+                Op2QAllLayer(op=tq.SSWAP, n_wires=self.n_wires, jump=1, circular=True)
+            )
 
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.U1,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True
-                ))
+                    op=tq.U1, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(
                 Op2QAllLayer(
                     op=tq.CU3,
@@ -802,7 +799,9 @@ class MaxwellLayer0(LayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
 
         return layers_all
 
@@ -810,13 +809,12 @@ class MaxwellLayer0(LayerTemplate0):
 class RYRYCXLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(CXLayer(n_wires=self.n_wires))
         return layers_all
 
@@ -824,13 +822,12 @@ class RYRYCXLayer0(LayerTemplate0):
 class RYRYRYCXCXCXLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(CXCXCXLayer(n_wires=self.n_wires))
         return layers_all
 
@@ -838,26 +835,24 @@ class RYRYRYCXCXCXLayer0(LayerTemplate0):
 class RYRYRYLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
         return layers_all
 
 
 class RYRYRYSWAPSWAPLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(SWAPSWAPLayer(n_wires=self.n_wires))
         return layers_all
 
@@ -865,7 +860,7 @@ class RYRYRYSWAPSWAPLayer0(LayerTemplate0):
 class SWAPSWAPLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(SWAPSWAPLayer(n_wires=self.n_wires))
         return layers_all
 
@@ -873,49 +868,43 @@ class SWAPSWAPLayer0(LayerTemplate0):
 class RXYZCXLayer0(LayerTemplate0):
     def build_layers(self):
         layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RX,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RX, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(
                 Op1QAllLayer(
-                    op=tq.RZ,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             layers_all.append(
-                Op2QAllLayer(
-                    op=tq.CNOT,
-                    n_wires=self.n_wires,
-                    jump=1,
-                    circular=True))
+                Op2QAllLayer(op=tq.CNOT, n_wires=self.n_wires, jump=1, circular=True)
+            )
         return layers_all
 
 
 layer_name_dict = {
-    'u3cu3_0': U3CU3Layer0,
-    'cu3_0': CU3Layer0,
-    'cxrzsx_0': CXRZSXLayer0,
-    'seth_0': SethLayer0,
-    'seth_1': SethLayer1,
-    'seth_2': SethLayer2,
-    'rzz_0': RZZLayer0,
-    'barren_0': BarrenLayer0,
-    'farhi_0': FarhiLayer0,
-    'maxwell_0': MaxwellLayer0,
-    'ryrycx': RYRYCXLayer0,
-    'ryryrycxcxcx': RYRYRYCXCXCXLayer0,
-    'ryryry': RYRYRYLayer0,
-    'swapswap': SWAPSWAPLayer0, 
-    'ryryryswapswap': RYRYRYSWAPSWAPLayer0,
-    'rxyzcx_0': RXYZCXLayer0
+    "u3cu3_0": U3CU3Layer0,
+    "cu3_0": CU3Layer0,
+    "cxrzsx_0": CXRZSXLayer0,
+    "seth_0": SethLayer0,
+    "seth_1": SethLayer1,
+    "seth_2": SethLayer2,
+    "rzz_0": RZZLayer0,
+    "barren_0": BarrenLayer0,
+    "farhi_0": FarhiLayer0,
+    "maxwell_0": MaxwellLayer0,
+    "ryrycx": RYRYCXLayer0,
+    "ryryrycxcxcx": RYRYRYCXCXCXLayer0,
+    "ryryry": RYRYRYLayer0,
+    "swapswap": SWAPSWAPLayer0,
+    "ryryryswapswap": RYRYRYSWAPSWAPLayer0,
+    "rxyzcx_0": RXYZCXLayer0,
 }
