@@ -3,17 +3,18 @@ import itertools
 
 from typing import List, Iterable
 
-__all__ = ['SuperQuantumModule',
-           'Super1QLayer',
-           'Super2QLayer',
-           'Super1QShareFrontLayer',
-           'Super1QSingleWireLayer',
-           'Super1QAllButOneLayer',
-           'Super2QAllShareFrontLayer',
-           'Super2QAllLayer',
-           'Super2QAlterLayer',
-           'super_layer_name_dict',
-           ]
+__all__ = [
+    "SuperQuantumModule",
+    "Super1QLayer",
+    "Super2QLayer",
+    "Super1QShareFrontLayer",
+    "Super1QSingleWireLayer",
+    "Super1QAllButOneLayer",
+    "Super2QAllShareFrontLayer",
+    "Super2QAllLayer",
+    "Super2QAlterLayer",
+    "super_layer_name_dict",
+]
 
 
 def get_combs(inset: List, n=None) -> List[List]:
@@ -55,8 +56,7 @@ class Super1QLayer(SuperQuantumModule):
         self.sample_wires = None
         self.ops_all = tq.QuantumModuleList()
         for k in range(n_wires):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
@@ -74,8 +74,9 @@ class Super1QLayer(SuperQuantumModule):
 
 
 class Super2QLayer(SuperQuantumModule):
-    def __init__(self, op, n_wires: int, has_params=False, trainable=False,
-                 wire_reverse=False):
+    def __init__(
+        self, op, n_wires: int, has_params=False, trainable=False, wire_reverse=False
+    ):
         super().__init__(n_wires=n_wires)
         self.op = op
         self.ops_all = tq.QuantumModuleList()
@@ -83,22 +84,21 @@ class Super2QLayer(SuperQuantumModule):
         # reverse the wires, for example from [1, 2] to [2, 1]
         self.wire_reverse = wire_reverse
         for k in range(n_wires):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
         for k in range(self.n_wires):
-            if [k, (k + 1) % self.n_wires] in self.sample_arch or \
-                    [(k + 1) % self.n_wires, k] in self.sample_arch:
-                wires = sorted([k, (k + 1) % self.n_wires],
-                               reverse=self.wire_reverse)
+            if [k, (k + 1) % self.n_wires] in self.sample_arch or [
+                (k + 1) % self.n_wires,
+                k,
+            ] in self.sample_arch:
+                wires = sorted([k, (k + 1) % self.n_wires], reverse=self.wire_reverse)
                 self.ops_all[k](q_device, wires=wires)
 
     @property
     def arch_space(self):
-        choices = list(map(list, itertools.combinations(list(range(
-            self.n_wires)), 2)))
+        choices = list(map(list, itertools.combinations(list(range(self.n_wires)), 2)))
         return get_combs(choices)
 
     def count_sample_params(self):
@@ -107,19 +107,21 @@ class Super2QLayer(SuperQuantumModule):
 
 class Super1QShareFrontLayer(SuperQuantumModule):
     """Share the front wires, the rest can be added"""
-    def __init__(self,
-                 op,
-                 n_wires: int,
-                 n_front_share_wires: int,
-                 has_params=False,
-                 trainable=False,):
+
+    def __init__(
+        self,
+        op,
+        n_wires: int,
+        n_front_share_wires: int,
+        has_params=False,
+        trainable=False,
+    ):
         super().__init__(n_wires=n_wires)
         self.n_front_share_wires = n_front_share_wires
         self.op = op
         self.ops_all = tq.QuantumModuleList()
         for k in range(n_wires):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
@@ -138,17 +140,19 @@ class Super1QShareFrontLayer(SuperQuantumModule):
 
 class Super1QSingleWireLayer(SuperQuantumModule):
     """Only one wire will have a gate"""
-    def __init__(self,
-                 op,
-                 n_wires: int,
-                 has_params=False,
-                 trainable=False,):
+
+    def __init__(
+        self,
+        op,
+        n_wires: int,
+        has_params=False,
+        trainable=False,
+    ):
         super().__init__(n_wires=n_wires)
         self.op = op
         self.ops_all = tq.QuantumModuleList()
         for k in range(n_wires):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
@@ -166,17 +170,19 @@ class Super1QSingleWireLayer(SuperQuantumModule):
 
 class Super1QAllButOneLayer(SuperQuantumModule):
     """Only one wire will NOT have the gate"""
-    def __init__(self,
-                 op,
-                 n_wires: int,
-                 has_params=False,
-                 trainable=False,):
+
+    def __init__(
+        self,
+        op,
+        n_wires: int,
+        has_params=False,
+        trainable=False,
+    ):
         super().__init__(n_wires=n_wires)
         self.op = op
         self.ops_all = tq.QuantumModuleList()
         for k in range(n_wires):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
@@ -208,9 +214,18 @@ class Super2QAllShareFrontLayer(SuperQuantumModule):
     jump = 4: [0, 4], [1, 5], [2, 0], [3, 1], [4, 2], [5, 3]
     jump = 5: [0, 5], [1, 0], [2, 1], [3, 2], [4, 3], [5, 4]
     """
-    def __init__(self, op, n_wires: int, n_front_share_ops: int,
-                 has_params=False, trainable=False,
-                 wire_reverse=False, jump=1, circular=False):
+
+    def __init__(
+        self,
+        op,
+        n_wires: int,
+        n_front_share_ops: int,
+        has_params=False,
+        trainable=False,
+        wire_reverse=False,
+        jump=1,
+        circular=False,
+    ):
         super().__init__(n_wires=n_wires)
         self.op = op
         self.n_front_share_ops = n_front_share_ops
@@ -226,8 +241,7 @@ class Super2QAllShareFrontLayer(SuperQuantumModule):
         else:
             self.n_ops = n_wires - jump
         for k in range(self.n_ops):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
@@ -263,9 +277,17 @@ class Super2QAllLayer(SuperQuantumModule):
     jump = 4: [0, 4], [1, 5], [2, 0], [3, 1], [4, 2], [5, 3]
     jump = 5: [0, 5], [1, 0], [2, 1], [3, 2], [4, 3], [5, 4]
     """
-    def __init__(self, op, n_wires: int,
-                 has_params=False, trainable=False,
-                 wire_reverse=False, jump=1, circular=False):
+
+    def __init__(
+        self,
+        op,
+        n_wires: int,
+        has_params=False,
+        trainable=False,
+        wire_reverse=False,
+        jump=1,
+        circular=False,
+    ):
         super().__init__(n_wires=n_wires)
         self.op = op
         self.jump = jump
@@ -280,8 +302,7 @@ class Super2QAllLayer(SuperQuantumModule):
         else:
             self.n_ops = n_wires - jump
         for k in range(self.n_ops):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
 
     @tq.static_support
     def forward(self, q_device):
@@ -290,8 +311,7 @@ class Super2QAllLayer(SuperQuantumModule):
             if self.wire_reverse:
                 wires.reverse()
 
-            if wires in self.sample_arch or list(reversed(wires)) in \
-                    self.sample_arch:
+            if wires in self.sample_arch or list(reversed(wires)) in self.sample_arch:
                 self.ops_all[k](q_device, wires=wires)
 
     @property
@@ -315,9 +335,16 @@ class Super2QAlterLayer(SuperQuantumModule):
     jump = 5: [0, 5]
     jump = 6: [0, 6]
     """
-    def __init__(self, op, n_wires: int,
-                 has_params=False, trainable=False,
-                 wire_reverse=False, jump=1):
+
+    def __init__(
+        self,
+        op,
+        n_wires: int,
+        has_params=False,
+        trainable=False,
+        wire_reverse=False,
+        jump=1,
+    ):
         super().__init__(n_wires=n_wires)
         self.op = op
         self.jump = jump
@@ -328,8 +355,7 @@ class Super2QAlterLayer(SuperQuantumModule):
         self.ops_all = tq.QuantumModuleList()
         self.n_ops = (n_wires - 1) // jump
         for k in range(self.n_ops):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
         self.wires_choices = []
         k = 0
         while k < n_wires:
@@ -350,8 +376,7 @@ class Super2QAlterLayer(SuperQuantumModule):
             if self.wire_reverse:
                 wires.reverse()
 
-            if wires in self.sample_arch or list(reversed(wires)) in \
-                    self.sample_arch:
+            if wires in self.sample_arch or list(reversed(wires)) in self.sample_arch:
                 self.ops_all[k](q_device, wires=wires)
 
     @property
@@ -371,9 +396,17 @@ class Super2QAlterShareFrontLayer(SuperQuantumModule):
     jump = 5: [0, 5]
     jump = 6: [0, 6]
     """
-    def __init__(self, op, n_wires: int, n_front_share_ops: int,
-                 has_params=False, trainable=False,
-                 wire_reverse=False, jump=1):
+
+    def __init__(
+        self,
+        op,
+        n_wires: int,
+        n_front_share_ops: int,
+        has_params=False,
+        trainable=False,
+        wire_reverse=False,
+        jump=1,
+    ):
         super().__init__(n_wires=n_wires)
         self.op = op
         self.n_front_share_ops = n_front_share_ops
@@ -385,8 +418,7 @@ class Super2QAlterShareFrontLayer(SuperQuantumModule):
         self.ops_all = tq.QuantumModuleList()
         self.n_ops = (n_wires - 1) // jump
         for k in range(self.n_ops):
-            self.ops_all.append(op(has_params=has_params,
-                                   trainable=trainable))
+            self.ops_all.append(op(has_params=has_params, trainable=trainable))
         self.wires_choices = []
         k = 0
         while k < n_wires:
@@ -421,15 +453,15 @@ class Super2QAlterShareFrontLayer(SuperQuantumModule):
 
 class SuperLayerTemplate0(SuperQuantumModule):
     def __init__(self, arch: dict = None):
-        super().__init__(n_wires=arch['n_wires'])
+        super().__init__(n_wires=arch["n_wires"])
         self.arch = arch
 
-        self.n_front_share_wires = arch.get('n_front_share_wires', None)
-        self.n_front_share_ops = arch.get('n_front_share_ops', None)
+        self.n_front_share_wires = arch.get("n_front_share_wires", None)
+        self.n_front_share_ops = arch.get("n_front_share_ops", None)
 
-        self.n_blocks = arch.get('n_blocks', None)
-        self.n_layers_per_block = arch.get('n_layers_per_block', None)
-        self.n_front_share_blocks = arch.get('n_front_share_blocks', None)
+        self.n_blocks = arch.get("n_blocks", None)
+        self.n_layers_per_block = arch.get("n_layers_per_block", None)
+        self.n_front_share_blocks = arch.get("n_front_share_blocks", None)
 
         self.sample_n_blocks = None
 
@@ -460,16 +492,19 @@ class SuperLayerTemplate0(SuperQuantumModule):
 
 class SuperU3CU3ShareFrontLayer0(SuperLayerTemplate0):
     """u3 cu3 blocks"""
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.U3,
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 Super2QAllShareFrontLayer(
                     op=tq.CU3,
@@ -478,21 +513,23 @@ class SuperU3CU3ShareFrontLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return super_layers_all
 
 
 class SuperU3CU3ArbitraryLayer0(SuperLayerTemplate0):
     """u3 cu3 blocks arbitrary n gates"""
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 Super1QLayer(
-                    op=tq.U3,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.U3, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             super_layers_all.append(
                 Super2QAllLayer(
                     op=tq.CU3,
@@ -500,93 +537,97 @@ class SuperU3CU3ArbitraryLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return super_layers_all
 
 
 class SuperIBMBasisShareFrontLayer0(SuperLayerTemplate0):
     """cnot rz sx x share front blocks"""
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.RZ,
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.PauliX,
                     n_wires=self.n_wires,
-                    n_front_share_wires=self.n_front_share_wires))
+                    n_front_share_wires=self.n_front_share_wires,
+                )
+            )
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.RZ,
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.SX,
                     n_wires=self.n_wires,
-                    n_front_share_wires=self.n_front_share_wires))
+                    n_front_share_wires=self.n_front_share_wires,
+                )
+            )
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.RZ,
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 Super2QAllShareFrontLayer(
                     op=tq.CNOT,
                     n_wires=self.n_wires,
                     n_front_share_ops=self.n_front_share_ops,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return super_layers_all
 
 
 class SuperIBMBasisArbitraryLayer0(SuperLayerTemplate0):
     """cnot rz sx x blocks arbitrary n gates"""
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 Super1QLayer(
-                    op=tq.RZ,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
+            super_layers_all.append(Super1QLayer(op=tq.PauliX, n_wires=self.n_wires))
             super_layers_all.append(
                 Super1QLayer(
-                    op=tq.PauliX,
-                    n_wires=self.n_wires))
+                    op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
+            super_layers_all.append(Super1QLayer(op=tq.SX, n_wires=self.n_wires))
             super_layers_all.append(
                 Super1QLayer(
-                    op=tq.RZ,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             super_layers_all.append(
-                Super1QLayer(
-                    op=tq.SX,
-                    n_wires=self.n_wires))
-            super_layers_all.append(
-                Super1QLayer(
-                    op=tq.RZ,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
-            super_layers_all.append(
-                Super2QAllLayer(
-                    op=tq.CNOT,
-                    n_wires=self.n_wires,
-                    jump=1,
-                    circular=True))
+                Super2QAllLayer(op=tq.CNOT, n_wires=self.n_wires, jump=1, circular=True)
+            )
         return super_layers_all
 
 
@@ -595,9 +636,10 @@ class SuperSethArbitraryLayer0(SuperLayerTemplate0):
     zz and ry blocks arbitrary n gates, from Seth Lloyd paper
     https://arxiv.org/pdf/2001.03622.pdf
     """
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 Super2QAllLayer(
                     op=tq.RZZ,
@@ -605,13 +647,14 @@ class SuperSethArbitraryLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
             super_layers_all.append(
                 Super1QLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
         return super_layers_all
 
 
@@ -620,9 +663,10 @@ class SuperSethShareFrontLayer0(SuperLayerTemplate0):
     zz and ry blocks share front n gates, from Seth Lloyd paper
     https://arxiv.org/pdf/2001.03622.pdf
     """
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 Super2QAllShareFrontLayer(
                     op=tq.RZZ,
@@ -631,14 +675,18 @@ class SuperSethShareFrontLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.RY,
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
         return super_layers_all
 
 
@@ -647,36 +695,31 @@ class SuperBarrenArbitraryLayer0(SuperLayerTemplate0):
     rx ry rz and cz blocks arbitrary n gates, from Barren plateaus paper
     https://arxiv.org/pdf/1803.11173.pdf
     """
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
 
-        super_layers_all.append(
-            Super1QLayer(op=tq.SHadamard, n_wires=self.n_wires))
+        super_layers_all.append(Super1QLayer(op=tq.SHadamard, n_wires=self.n_wires))
 
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 Super1QLayer(
-                    op=tq.RX,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RX, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             super_layers_all.append(
                 Super1QLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             super_layers_all.append(
                 Super1QLayer(
-                    op=tq.RZ,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             super_layers_all.append(
-                Super2QAlterLayer(
-                    op=tq.CZ,
-                    n_wires=self.n_wires,
-                    jump=1))
+                Super2QAlterLayer(op=tq.CZ, n_wires=self.n_wires, jump=1)
+            )
         return super_layers_all
 
 
@@ -685,6 +728,7 @@ class SuperBarrenShareFrontLayer0(SuperLayerTemplate0):
     rx ry rz and cz blocks share front n gates, from Barren plateaus paper
     https://arxiv.org/pdf/1803.11173.pdf
     """
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
 
@@ -692,37 +736,46 @@ class SuperBarrenShareFrontLayer0(SuperLayerTemplate0):
             Super1QShareFrontLayer(
                 op=tq.SHadamard,
                 n_wires=self.n_wires,
-                n_front_share_wires=self.n_front_share_wires
-            ))
+                n_front_share_wires=self.n_front_share_wires,
+            )
+        )
 
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.RX,
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.RY,
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 Super1QShareFrontLayer(
                     op=tq.RZ,
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 Super2QAlterShareFrontLayer(
                     op=tq.CZ,
                     n_wires=self.n_wires,
                     n_front_share_ops=self.n_front_share_ops,
-                    jump=1))
+                    jump=1,
+                )
+            )
         return super_layers_all
 
 
@@ -731,10 +784,11 @@ class SuperFarhiArbitraryLayer0(SuperLayerTemplate0):
     zx and xx blocks arbitrary n gates, from Farhi paper
     https://arxiv.org/pdf/1802.06002.pdf
     """
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
 
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 tq.Super2QAllLayer(
                     op=tq.RZX,
@@ -742,7 +796,9 @@ class SuperFarhiArbitraryLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
             super_layers_all.append(
                 tq.Super2QAllLayer(
                     op=tq.RXX,
@@ -750,7 +806,9 @@ class SuperFarhiArbitraryLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return super_layers_all
 
 
@@ -759,10 +817,11 @@ class SuperFarhiShareFrontLayer0(SuperLayerTemplate0):
     zx and xx blocks share front n gates, from Farhi paper
     https://arxiv.org/pdf/1802.06002.pdf
     """
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
 
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 tq.Super2QAllShareFrontLayer(
                     op=tq.RZX,
@@ -771,7 +830,9 @@ class SuperFarhiShareFrontLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
             super_layers_all.append(
                 tq.Super2QAllShareFrontLayer(
                     op=tq.RXX,
@@ -780,7 +841,9 @@ class SuperFarhiShareFrontLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
         return super_layers_all
 
 
@@ -790,67 +853,52 @@ class SuperMaxwellArbitraryLayer0(SuperLayerTemplate0):
     blocks arbitrary n gates, from Maxwell paper
     https://arxiv.org/pdf/1904.04767.pdf
     """
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
 
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 tq.Super1QLayer(
-                    op=tq.RX,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
-            super_layers_all.append(
-                tq.Super1QLayer(
-                    op=tq.S,
-                    n_wires=self.n_wires))
+                    op=tq.RX, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
+            super_layers_all.append(tq.Super1QLayer(op=tq.S, n_wires=self.n_wires))
             super_layers_all.append(
                 tq.Super2QAllLayer(
-                    op=tq.CNOT,
-                    n_wires=self.n_wires,
-                    jump=1,
-                    circular=True))
+                    op=tq.CNOT, n_wires=self.n_wires, jump=1, circular=True
+                )
+            )
 
             super_layers_all.append(
                 tq.Super1QLayer(
-                    op=tq.RY,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
-            super_layers_all.append(
-                tq.Super1QLayer(
-                    op=tq.T,
-                    n_wires=self.n_wires))
+                    op=tq.RY, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
+            super_layers_all.append(tq.Super1QLayer(op=tq.T, n_wires=self.n_wires))
             super_layers_all.append(
                 tq.Super2QAllLayer(
-                    op=tq.SWAP,
-                    n_wires=self.n_wires,
-                    jump=1,
-                    circular=True))
+                    op=tq.SWAP, n_wires=self.n_wires, jump=1, circular=True
+                )
+            )
 
             super_layers_all.append(
                 tq.Super1QLayer(
-                    op=tq.RZ,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
-            super_layers_all.append(
-                tq.Super1QLayer(
-                    op=tq.T,
-                    n_wires=self.n_wires))
+                    op=tq.RZ, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
+            super_layers_all.append(tq.Super1QLayer(op=tq.T, n_wires=self.n_wires))
             super_layers_all.append(
                 tq.Super2QAllLayer(
-                    op=tq.SSWAP,
-                    n_wires=self.n_wires,
-                    jump=1,
-                    circular=True))
+                    op=tq.SSWAP, n_wires=self.n_wires, jump=1, circular=True
+                )
+            )
 
             super_layers_all.append(
                 tq.Super1QLayer(
-                    op=tq.U1,
-                    n_wires=self.n_wires,
-                    has_params=True,
-                    trainable=True))
+                    op=tq.U1, n_wires=self.n_wires, has_params=True, trainable=True
+                )
+            )
             super_layers_all.append(
                 tq.Super2QAllLayer(
                     op=tq.CU3,
@@ -858,7 +906,9 @@ class SuperMaxwellArbitraryLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
 
         return super_layers_all
 
@@ -869,29 +919,36 @@ class SuperMaxwellShareFrontLayer0(SuperLayerTemplate0):
     blocks share front n gates, from Maxwell paper
     https://arxiv.org/pdf/1904.04767.pdf
     """
+
     def build_super_layers(self):
         super_layers_all = tq.QuantumModuleList()
 
-        for k in range(self.arch['n_blocks']):
+        for k in range(self.arch["n_blocks"]):
             super_layers_all.append(
                 tq.Super1QShareFrontLayer(
                     op=tq.RX,
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 tq.Super1QShareFrontLayer(
                     op=tq.S,
                     n_wires=self.n_wires,
-                    n_front_share_wires=self.n_front_share_wires))
+                    n_front_share_wires=self.n_front_share_wires,
+                )
+            )
             super_layers_all.append(
                 tq.Super2QAllShareFrontLayer(
                     op=tq.CNOT,
                     n_wires=self.n_wires,
                     n_front_share_ops=self.n_front_share_ops,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
 
             super_layers_all.append(
                 tq.Super1QShareFrontLayer(
@@ -899,19 +956,25 @@ class SuperMaxwellShareFrontLayer0(SuperLayerTemplate0):
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 tq.Super1QShareFrontLayer(
                     op=tq.T,
                     n_wires=self.n_wires,
-                    n_front_share_wires=self.n_front_share_wires))
+                    n_front_share_wires=self.n_front_share_wires,
+                )
+            )
             super_layers_all.append(
                 tq.Super2QAllShareFrontLayer(
                     op=tq.SWAP,
                     n_wires=self.n_wires,
                     n_front_share_ops=self.n_front_share_ops,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
 
             super_layers_all.append(
                 tq.Super1QShareFrontLayer(
@@ -919,19 +982,25 @@ class SuperMaxwellShareFrontLayer0(SuperLayerTemplate0):
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 tq.Super1QShareFrontLayer(
                     op=tq.T,
                     n_wires=self.n_wires,
-                    n_front_share_wires=self.n_front_share_wires))
+                    n_front_share_wires=self.n_front_share_wires,
+                )
+            )
             super_layers_all.append(
                 tq.Super2QAllShareFrontLayer(
                     op=tq.SSWAP,
                     n_wires=self.n_wires,
                     n_front_share_ops=self.n_front_share_ops,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
 
             super_layers_all.append(
                 tq.Super1QShareFrontLayer(
@@ -939,7 +1008,9 @@ class SuperMaxwellShareFrontLayer0(SuperLayerTemplate0):
                     n_wires=self.n_wires,
                     n_front_share_wires=self.n_front_share_wires,
                     has_params=True,
-                    trainable=True))
+                    trainable=True,
+                )
+            )
             super_layers_all.append(
                 tq.Super2QAllShareFrontLayer(
                     op=tq.CU3,
@@ -948,22 +1019,24 @@ class SuperMaxwellShareFrontLayer0(SuperLayerTemplate0):
                     has_params=True,
                     trainable=True,
                     jump=1,
-                    circular=True))
+                    circular=True,
+                )
+            )
 
         return super_layers_all
 
 
 super_layer_name_dict = {
-    'u3cu3_s0': SuperU3CU3ShareFrontLayer0,
-    'seth_s0': SuperSethShareFrontLayer0,
-    'barren_s0': SuperBarrenShareFrontLayer0,
-    'farhi_s0': SuperFarhiShareFrontLayer0,
-    'maxwell_s0': SuperMaxwellShareFrontLayer0,
-    'ibmbasis_s0': SuperIBMBasisShareFrontLayer0,
-    'u3cu3_a0': SuperU3CU3ArbitraryLayer0,
-    'seth_a0': SuperSethArbitraryLayer0,
-    'barren_a0': SuperBarrenArbitraryLayer0,
-    'farhi_a0': SuperFarhiArbitraryLayer0,
-    'maxwell_a0': SuperMaxwellArbitraryLayer0,
-    'ibmbasis_a0': SuperIBMBasisArbitraryLayer0,
+    "u3cu3_s0": SuperU3CU3ShareFrontLayer0,
+    "seth_s0": SuperSethShareFrontLayer0,
+    "barren_s0": SuperBarrenShareFrontLayer0,
+    "farhi_s0": SuperFarhiShareFrontLayer0,
+    "maxwell_s0": SuperMaxwellShareFrontLayer0,
+    "ibmbasis_s0": SuperIBMBasisShareFrontLayer0,
+    "u3cu3_a0": SuperU3CU3ArbitraryLayer0,
+    "seth_a0": SuperSethArbitraryLayer0,
+    "barren_a0": SuperBarrenArbitraryLayer0,
+    "farhi_a0": SuperFarhiArbitraryLayer0,
+    "maxwell_a0": SuperMaxwellArbitraryLayer0,
+    "ibmbasis_a0": SuperIBMBasisArbitraryLayer0,
 }
