@@ -21,35 +21,37 @@ if TYPE_CHECKING:
     from torchquantum.devices import QuantumDevice
 else:
     QuantumModule = None
-    QuantumDevice= None
+    QuantumDevice = None
 
 
-__all__ = ['pauli_eigs', 
-            'diag', 
-            'Timer', 
-            'get_unitary_loss', 
-            'legalize_unitary',
-            'switch_little_big_endian_matrix', 
-            'switch_little_big_endian_state',
-            'get_expectations_from_counts', 
-            'find_global_phase',
-            'build_module_op_list', 
-            'build_module_from_op_list',
-            'build_module_description_test',
-            'get_p_v_reg_mapping',
-            'get_p_c_reg_mapping',
-            'get_v_c_reg_mapping',
-            'get_cared_configs',
-            'get_success_rate',
-            'get_provider',
-            'get_provider_hub_group_project',
-            'normalize_statevector',
-            'get_circ_stats',
-            'partial_trace',
-            'tensor_form',
-            'matrix_form',
-            'dm_to_mixture_of_state',
-           ]
+__all__ = [
+    "pauli_eigs",
+    "diag",
+    "Timer",
+    "get_unitary_loss",
+    "legalize_unitary",
+    "switch_little_big_endian_matrix",
+    "switch_little_big_endian_state",
+    "get_expectations_from_counts",
+    "find_global_phase",
+    "build_module_op_list",
+    "build_module_from_op_list",
+    "build_module_description_test",
+    "get_p_v_reg_mapping",
+    "get_p_c_reg_mapping",
+    "get_v_c_reg_mapping",
+    "get_cared_configs",
+    "get_success_rate",
+    "get_provider",
+    "get_provider_hub_group_project",
+    "normalize_statevector",
+    "get_circ_stats",
+    "partial_trace",
+    "tensor_form",
+    "matrix_form",
+    "dm_to_mixture_of_state",
+]
+
 
 def pauli_eigs(n) -> np.ndarray:
     r"""Eigenvalues for :math:`A^{\o times n}`, where :math:`A` is
@@ -75,44 +77,45 @@ def diag(x):
     diag_len = x.shape[-1]
     x = x.unsqueeze(-1)
     dims = list(x.shape)
-    x = torch.cat([x, torch.zeros(dims[:-1] + [diag_len]).to(x.device)],
-                  dim=-1)
+    x = torch.cat([x, torch.zeros(dims[:-1] + [diag_len]).to(x.device)], dim=-1)
     x = x.view(dims[:-2] + [diag_len * (diag_len + 1)])[..., :-diag_len]
     x = x.view(dims[:-2] + [diag_len, diag_len])
     return x
 
 
 class Timer(object):
-    def __init__(self, device='gpu', name='', times=100):
+    def __init__(self, device="gpu", name="", times=100):
         self.device = device
         self.name = name
         self.times = times
-        if device == 'gpu':
+        if device == "gpu":
             self.start = torch.cuda.Event(enable_timing=True)
             self.end = torch.cuda.Event(enable_timing=True)
 
     def __enter__(self):
-        if self.device == 'gpu':
+        if self.device == "gpu":
             self.start.record()
 
     def __exit__(self, exc_type, exc_value, tb):
-        if self.device == 'gpu':
+        if self.device == "gpu":
             self.end.record()
             torch.cuda.synchronize()
-            print(f"Task: {self.name}: "
-                  f"{self.start.elapsed_time(self.end) / self.times} ms")
+            print(
+                f"Task: {self.name}: "
+                f"{self.start.elapsed_time(self.end) / self.times} ms"
+            )
 
 
 def get_unitary_loss(model: nn.Module):
     loss = 0
     for name, params in model.named_parameters():
-        if 'TrainableUnitary' in name:
+        if "TrainableUnitary" in name:
             U = params
             like_identity = U.matmul(U.conj().permute(0, 2, 1))
-            identity = torch.eye(U.shape[0], dtype=C_DTYPE,
-                                 device=U.device)
-            loss += F.mse_loss(torch.view_as_real(identity),
-                               torch.view_as_real(like_identity))
+            identity = torch.eye(U.shape[0], dtype=C_DTYPE, device=U.device)
+            loss += F.mse_loss(
+                torch.view_as_real(identity), torch.view_as_real(like_identity)
+            )
 
     return loss
 
@@ -120,7 +123,7 @@ def get_unitary_loss(model: nn.Module):
 def legalize_unitary(model: nn.Module):
     with torch.no_grad():
         for name, params in model.named_parameters():
-            if 'TrainableUnitary' in name:
+            if "TrainableUnitary" in name:
                 U = params
                 U, Sigma, V = torch.svd(U)
                 params.data.copy_(U.matmul(V.conj().permute(0, 2, 1)))
@@ -195,7 +198,7 @@ def get_expectations_from_counts(counts, n_wires):
         total_shots = 0
         for k, v in count.items():
             for wire in range(n_wires):
-                if k[wire] == '1':
+                if k[wire] == "1":
                     ctr_one[wire] += v
             total_shots += v
         prob_one = np.array(ctr_one) / total_shots
@@ -209,8 +212,7 @@ def find_global_phase(mat1, mat2, threshold):
     for i in range(mat1.shape[0]):
         for j in range(mat1.shape[1]):
             # find a numerical stable global phase
-            if np.abs(mat1[i][j]) > threshold and \
-                    np.abs(mat2[i][j]) > threshold:
+            if np.abs(mat1[i][j]) > threshold and np.abs(mat2[i][j]) > threshold:
                 return mat2[i][j] / mat1[i][j]
     return None
 
@@ -255,44 +257,49 @@ def build_module_op_list(m: QuantumModule, x=None) -> List:
         else:
             params = None
 
-        op_list.append({
-            'name': module.name.lower(),
-            'has_params': module.has_params,
-            'trainable': module.trainable,
-            'wires': module.wires,
-            'n_wires': module.n_wires,
-            'params': params
-        })
+        op_list.append(
+            {
+                "name": module.name.lower(),
+                "has_params": module.has_params,
+                "trainable": module.trainable,
+                "wires": module.wires,
+                "n_wires": module.n_wires,
+                "params": params,
+            }
+        )
 
     return op_list
 
 
-def build_module_from_op_list(op_list: List[Dict],
-                              remove_ops=False,
-                              thres=None) -> QuantumModule:
+def build_module_from_op_list(
+    op_list: List[Dict], remove_ops=False, thres=None
+) -> QuantumModule:
     logger.info(f"Building module from op_list...")
     thres = 1e-5 if thres is None else thres
     n_removed_ops = 0
     ops = []
     for info in op_list:
-        params = info['params']
+        params = info["params"]
 
         if remove_ops:
             if params is not None:
-                params = np.array(params) if isinstance(params, Iterable) \
+                params = (
+                    np.array(params)
+                    if isinstance(params, Iterable)
                     else np.array([params])
+                )
                 params = params % (2 * np.pi)
                 params[params > np.pi] -= 2 * np.pi
                 if all(abs(params) < thres):
                     n_removed_ops += 1
                     continue
 
-        op = tq.op_name_dict[info['name']](
-            has_params=info['has_params'],
-            trainable=info['trainable'],
-            wires=info['wires'],
-            n_wires=info['n_wires'],
-            init_params=info['params'],
+        op = tq.op_name_dict[info["name"]](
+            has_params=info["has_params"],
+            trainable=info["trainable"],
+            wires=info["wires"],
+            n_wires=info["n_wires"],
+            init_params=info["params"],
         )
         ops.append(op)
 
@@ -311,15 +318,17 @@ def build_module_description_test():
 
     pdb.set_trace()
     from examples.core.models.q_models import QFCModel12
-    q_model = QFCModel12({'n_blocks': 4})
+
+    q_model = QFCModel12({"n_blocks": 4})
     desc = build_module_op_list(q_model.q_layer)
     print(desc)
     q_dev = tq.QuantumDevice(n_wires=4)
     m = build_module_from_op_list(desc)
     tq2qiskit(q_dev, m, draw=True)
 
-    desc = build_module_op_list(tq.RandomLayerAllTypes(
-        n_ops=200,  wires=[0, 1, 2, 3], qiskit_compatible=True))
+    desc = build_module_op_list(
+        tq.RandomLayerAllTypes(n_ops=200, wires=[0, 1, 2, 3], qiskit_compatible=True)
+    )
     print(desc)
     m1 = build_module_from_op_list(desc)
     tq2qiskit(q_dev, m1, draw=True)
@@ -332,14 +341,14 @@ def get_p_v_reg_mapping(circ):
     """
     p2v_orig = circ._layout.get_physical_bits().copy()
     mapping = {
-        'p2v': {},
-        'v2p': {},
+        "p2v": {},
+        "v2p": {},
     }
 
     for p, v in p2v_orig.items():
-        if v.register.name == 'q':
-            mapping['p2v'][p] = v.index
-            mapping['v2p'][v.index] = p
+        if v.register.name == "q":
+            mapping["p2v"][p] = v.index
+            mapping["v2p"][v.index] = p
 
     return mapping
 
@@ -350,13 +359,13 @@ def get_p_c_reg_mapping(circ):
     c are classical registers
     """
     mapping = {
-        'p2c': {},
-        'c2p': {},
+        "p2c": {},
+        "c2p": {},
     }
     for gate in circ.data:
-        if gate[0].name == 'measure':
-            mapping['p2c'][gate[1][0].index] = gate[2][0].index
-            mapping['c2p'][gate[2][0].index] = gate[1][0].index
+        if gate[0].name == "measure":
+            mapping["p2c"][gate[1][0].index] = gate[2][0].index
+            mapping["c2p"][gate[2][0].index] = gate[1][0].index
 
     return mapping
 
@@ -372,28 +381,25 @@ def get_v_c_reg_mapping(circ):
     p2v_orig = circ._layout.get_physical_bits().copy()
     p2v = {}
     for p, v in p2v_orig.items():
-        if v.register.name == 'q':
+        if v.register.name == "q":
             p2v[p] = v.index
 
     mapping = {
-        'p2c': {},
-        'c2p': {},
+        "p2c": {},
+        "c2p": {},
     }
     for gate in circ.data:
-        if gate[0].name == 'measure':
-            mapping['p2c'][gate[1][0].index] = gate[2][0].index
-            mapping['c2p'][gate[2][0].index] = gate[1][0].index
+        if gate[0].name == "measure":
+            mapping["p2c"][gate[1][0].index] = gate[2][0].index
+            mapping["c2p"][gate[2][0].index] = gate[1][0].index
 
-    mapping2 = {
-        'v2c': {},
-        'c2v': {}
-    }
+    mapping2 = {"v2c": {}, "c2v": {}}
 
-    for c, p in mapping['c2p'].items():
-        mapping2['c2v'][c] = p2v[p]
+    for c, p in mapping["c2p"].items():
+        mapping2["c2v"][c] = p2v[p]
 
-    for c, v in mapping2['c2v'].items():
-        mapping2['v2c'][v] = c
+    for c, v in mapping2["c2v"].items():
+        mapping2["v2c"][v] = c
 
     return mapping2
 
@@ -401,62 +407,62 @@ def get_v_c_reg_mapping(circ):
 def get_cared_configs(conf, mode) -> Config:
     """only preserve cared configs"""
     conf = copy.deepcopy(conf)
-    ignores = ['callbacks',
-               'criterion',
-               'debug',
-               'legalization',
-               'regularization',
-               'verbose',
-               'get_n_params',
-               'prune',
-               ]
+    ignores = [
+        "callbacks",
+        "criterion",
+        "debug",
+        "legalization",
+        "regularization",
+        "verbose",
+        "get_n_params",
+        "prune",
+    ]
 
-    if 'super' not in conf.trainer.name:
-        ignores.append('scheduler')
-        ignores.append('optimizer')
+    if "super" not in conf.trainer.name:
+        ignores.append("scheduler")
+        ignores.append("optimizer")
 
     for ignore in ignores:
         if hasattr(conf, ignore):
             delattr(conf, ignore)
 
-    if hasattr(conf, 'dataset'):
-        dataset_ignores = ['binarize',
-                           'binarize_threshold',
-                           'center_crop',
-                           'name',
-                           'resize',
-                           'resize_mode',
-                           'root',
-                           'train_valid_split_ratio',
-                           ]
+    if hasattr(conf, "dataset"):
+        dataset_ignores = [
+            "binarize",
+            "binarize_threshold",
+            "center_crop",
+            "name",
+            "resize",
+            "resize_mode",
+            "root",
+            "train_valid_split_ratio",
+        ]
         for dataset_ignore in dataset_ignores:
             if hasattr(conf.dataset, dataset_ignore):
                 delattr(conf.dataset, dataset_ignore)
 
-    if not mode == 'es' and hasattr(conf, 'es'):
-        delattr(conf, 'es')
-    elif mode == 'es' and hasattr(conf, 'es') and hasattr(conf.es, 'eval'):
-        delattr(conf.es, 'eval')
+    if not mode == "es" and hasattr(conf, "es"):
+        delattr(conf, "es")
+    elif mode == "es" and hasattr(conf, "es") and hasattr(conf.es, "eval"):
+        delattr(conf.es, "eval")
 
-    if not mode == 'train' and hasattr(conf, 'trainer'):
-        delattr(conf, 'trainer')
+    if not mode == "train" and hasattr(conf, "trainer"):
+        delattr(conf, "trainer")
 
-    if hasattr(conf, 'qiskit'):
+    if hasattr(conf, "qiskit"):
         qiskit_ignores = [
-                          'seed_simulator',
-                          'seed_transpiler',
-                          'coupling_map_name',
-                          'basis_gates_name',
-                          'est_success_rate',
-                          ]
+            "seed_simulator",
+            "seed_transpiler",
+            "coupling_map_name",
+            "basis_gates_name",
+            "est_success_rate",
+        ]
         for qiskit_ignore in qiskit_ignores:
             if hasattr(conf.qiskit, qiskit_ignore):
                 delattr(conf.qiskit, qiskit_ignore)
 
-    if hasattr(conf, 'run'):
-        run_ignores = ['device',
-                       'workers_per_gpu',
-                       'n_epochs']
+    if hasattr(conf, "run"):
+        run_ignores = ["device", "workers_per_gpu", "n_epochs"]
         for run_ignore in run_ignores:
             if hasattr(conf.run, run_ignore):
                 delattr(conf.run, run_ignore)
@@ -473,17 +479,15 @@ def get_success_rate(properties, transpiled_circ):
     gate_error_dict = {}
     for gate_error in gate_errors:
         if gate_error[0] not in gate_error_dict.keys():
-            gate_error_dict[gate_error[0]] = {tuple(gate_error[1]):
-                                              gate_error[2]}
+            gate_error_dict[gate_error[0]] = {tuple(gate_error[1]): gate_error[2]}
         else:
-            gate_error_dict[gate_error[0]][tuple(gate_error[1])] = \
-                gate_error[2]
+            gate_error_dict[gate_error[0]][tuple(gate_error[1])] = gate_error[2]
 
     success_rate = 1
     for gate in transpiled_circ.data:
-        gate_success_rate = 1 - gate_error_dict[gate[0].name][tuple(
-            map(lambda x: x.index, gate[1])
-        )]
+        gate_success_rate = (
+            1 - gate_error_dict[gate[0].name][tuple(map(lambda x: x.index, gate[1]))]
+        )
         if gate_success_rate == 0:
             gate_success_rate = 1e-5
         success_rate *= gate_success_rate
@@ -491,56 +495,48 @@ def get_success_rate(properties, transpiled_circ):
     return success_rate
 
 
-
 def get_provider(backend_name, hub=None):
     # mass-inst-tech-1 or MIT-1
-    if backend_name in ['ibmq_casablanca',
-                        'ibmq_rome',
-                        'ibmq_bogota',
-                        'ibmq_jakarta']:
-        if hub == 'mass' or hub is None:
-            provider = IBMQ.get_provider(hub='ibm-q-research',
-                                         group='mass-inst-tech-1',
-                                         project='main')
-        elif hub == 'mit':
-            provider = IBMQ.get_provider(hub='ibm-q-research',
-                                         group='MIT-1',
-                                         project='main')
+    if backend_name in ["ibmq_casablanca", "ibmq_rome", "ibmq_bogota", "ibmq_jakarta"]:
+        if hub == "mass" or hub is None:
+            provider = IBMQ.get_provider(
+                hub="ibm-q-research", group="mass-inst-tech-1", project="main"
+            )
+        elif hub == "mit":
+            provider = IBMQ.get_provider(
+                hub="ibm-q-research", group="MIT-1", project="main"
+            )
         else:
-            raise ValueError(f"not supported backend {backend_name} in hub "
-                             f"{hub}")
-    elif backend_name in ['ibmq_paris',
-                          'ibmq_toronto',
-                          'ibmq_manhattan',
-                          'ibmq_guadalupe',
-                          'ibmq_montreal',
-                          ]:
-        provider = IBMQ.get_provider(hub='ibm-q-ornl',
-                                     group='anl',
-                                     project='csc428')
+            raise ValueError(f"not supported backend {backend_name} in hub " f"{hub}")
+    elif backend_name in [
+        "ibmq_paris",
+        "ibmq_toronto",
+        "ibmq_manhattan",
+        "ibmq_guadalupe",
+        "ibmq_montreal",
+    ]:
+        provider = IBMQ.get_provider(hub="ibm-q-ornl", group="anl", project="csc428")
     else:
-        if hub == 'mass' or hub is None:
+        if hub == "mass" or hub is None:
             try:
-                provider = IBMQ.get_provider(hub='ibm-q-research',
-                                             group='mass-inst-tech-1',
-                                             project='main')
+                provider = IBMQ.get_provider(
+                    hub="ibm-q-research", group="mass-inst-tech-1", project="main"
+                )
             except QiskitError:
                 # logger.warning(f"Cannot use MIT backend, roll back to open")
                 logger.warning(f"Use the open backend")
-                provider = IBMQ.get_provider(hub='ibm-q')
-        elif hub == 'mit':
-            provider = IBMQ.get_provider(hub='ibm-q-research',
-                                         group='MIT-1',
-                                         project='main')
+                provider = IBMQ.get_provider(hub="ibm-q")
+        elif hub == "mit":
+            provider = IBMQ.get_provider(
+                hub="ibm-q-research", group="MIT-1", project="main"
+            )
         else:
-            provider = IBMQ.get_provider(hub='ibm-q')
+            provider = IBMQ.get_provider(hub="ibm-q")
 
     return provider
 
 
-def get_provider_hub_group_project(hub='ibm-q',
-                                   group='open',
-                                   project='main'):
+def get_provider_hub_group_project(hub="ibm-q", group="open", project="main"):
     provider = IBMQ.get_provider(
         hub=hub,
         group=group,
@@ -562,8 +558,7 @@ def normalize_statevector(states):
             if val == 0:
                 states_reshape[k][0] = 1
 
-    factors = torch.sqrt(1 / ((abs(states_reshape) ** 2).sum(
-        dim=-1))).unsqueeze(-1)
+    factors = torch.sqrt(1 / ((abs(states_reshape) ** 2).sum(dim=-1))).unsqueeze(-1)
     states = (states_reshape * factors).reshape(original_shape)
 
     return states
@@ -587,7 +582,7 @@ def get_circ_stats(circ):
         else:
             n_gates_dict[op_name] = 1
 
-        if op_name == 'measure':
+        if op_name == "measure":
             n_measure += 1
         elif len(wires) == 1:
             n_single_gates += 1
@@ -597,13 +592,13 @@ def get_circ_stats(circ):
             n_three_more_gates += 1
 
     return {
-        'depth': depth,
-        'size': size,
-        'width': width,
-        'n_single_gates': n_single_gates,
-        'n_two_gates': n_two_gates,
-        'n_three_more_gates': n_three_more_gates,
-        'n_gates_dict': n_gates_dict
+        "depth": depth,
+        "size": size,
+        "width": width,
+        "n_single_gates": n_single_gates,
+        "n_two_gates": n_two_gates,
+        "n_three_more_gates": n_three_more_gates,
+        "n_gates_dict": n_gates_dict,
     }
 
 
@@ -709,6 +704,7 @@ def dm_to_mixture_of_state(dm: torch.Tensor, atol=1e-10):
         mixture = tuple(zip(eigvals, [vec.reshape([2] * dims) for vec in eigvecs.T]))
         return tuple([(float(p[0]), p[1]) for p in mixture if p[0] > 1e-10])
 
+
 def partial_trace_test():
     import torchquantum.functional as tqf
 
@@ -721,9 +717,11 @@ def partial_trace_test():
     dms = partial_trace(q_device, [0])
     dms = matrix_form(dms)
     mixture = dm_to_mixture_of_state(dms)
-    
+
     print(mixture)
-if __name__ == '__main__':
+
+
+if __name__ == "__main__":
     build_module_description_test()
     switch_little_big_endian_matrix_test()
     switch_little_big_endian_state_test()
